# tree-sitter-bsl

[![CI][ci]](https://github.com/alkoleft/tree-sitter-bsl/actions/workflows/ci.yml)
[![npm][npm]](https://www.npmjs.com/package/tree-sitter-bsl)

Грамматика 1C (BSL) Language в формате [tree-sitter](https://github.com/tree-sitter/tree-sitter).

[Попробовать](https://alkoleft.github.io/tree-sitter-bsl/)

![playground](playground.png)

#### References

- Грамматика основана на правилах [BSL Parser](https://github.com/1c-syntax/bsl-parser)

[ci]: https://img.shields.io/github/actions/workflow/status/alkoleft/tree-sitter-bsl/ci.yml?logo=github&label=CI
[npm]: https://img.shields.io/npm/v/tree-sitter-bsl?logo=npm
[telegram]: https://img.shields.io/badge/Telegram-2CA5E0?style=Flat-square&logo=telegram&logoColor=white